# Copyright (C) 2023 Intel Corporation
# SPDX-License-Identifier: MIT
#
# This package is downstreamed from Intel GPU RHEL9.2 Package repository:
# https://dgpu-docs.intel.com/driver/installation.html#rhel-install-steps

%global pkg_name igsc
%global lib_ver 0.8.9
%global anolis_release 1

Name:		%{pkg_name}
Version:	%{lib_ver}
Release:	%{anolis_release}%{?dist}
Summary:	Intel(R) Graphics System Controller Firmware Update Library

Group:		System Environment/Libraries
License:	apache2
URL:		https://github.com/intel/igsc
Source0:	%{url}/archive/V%{ver}/%{name}-%{version}.tar.gz
ExclusiveArch:	x86_64

BuildRequires:	make
BuildRequires:	cmake
BuildRequires:	systemd-devel
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	libmetee-devel

%description
The Intel Graphics System Firmware Update Library (IGSC FUL) is a pure
C low level library that exposes a required API to perform a firmware
update of a particular Intel discrete graphics device. The library
utilized a cross platform library metee_ in order to access the GSC
(mei) device. GSC device is an extension of the Intel discrete graphics
device (dGFX).

The library can update GSC firmware itself, and as well as OPROM VBT and
the code (VBIOS, GOP).

The library provides retrieval of identity and version information from
both graphic device and supplied firmware or OPROM image as well as
function for firmware update of those images to the device.

%package -n	intel-gsc
Summary:	Intel(R) Graphics System Controller Firmware Update Library
Requires:	libmetee
%description -n intel-gsc
The Intel Graphics System Firmware Update Library (IGSC FUL) is a pure
C low level library that exposes a required API to perform a firmware
update of a particular Intel discrete graphics device. The library
utilized a cross platform library metee_ in order to access the GSC
(mei) device. GSC device is an extension of the Intel discrete graphics
device (dGFX).

The library can update GSC firmware itself, and as well as OPROM VBT and
the code (VBIOS, GOP).

The library provides retrieval of identity and version information from
both graphic device and supplied firmware or OPROM image as well as
function for firmware update of those images to the device.

%package -n	intel-gsc-devel
Summary:	Development headers for igsc
Requires:	intel-gsc
%description -n	intel-gsc-devel
The Intel Graphics System Firmware Update Library (IGSC FUL) is a pure
C low level library that exposes a required API to perform a firmware
update of a particular Intel discrete graphics device. The library
utilized a cross platform library metee_ in order to access the GSC
(mei) device. GSC device is an extension of the Intel discrete graphics
device (dGFX).

The library can update GSC firmware itself, and as well as OPROM VBT
and the code (VBIOS, GOP).

The library provides retrieval of identity and version information from
both graphic device and supplied firmware or OPROM image as well as
function for firmware update of those images to the device.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
mkdir build
pushd build
%cmake .. \
   -DCMAKE_BUILD_TYPE=Release \
   -DBUILD_SHARED_LIBS=ON
%cmake_build
popd

%install
pushd build
%cmake_install
popd

%files -n intel-gsc
%defattr(-,root,root)
%license LICENSE.txt
%{_bindir}/igsc
%{_libdir}/libigsc.so.*

%files -n intel-gsc-devel
%defattr(-,root,root)
%{_libdir}/libigsc.so
%{_includedir}/igsc_lib.h
/usr/lib/cmake/igsc/*.cmake

%changelog
* Fri Nov 17 2023 Aubrey Li <aubrey.li@linux.intel.com> - 0.8.9-1
- Initial spec file
